package com.mcwl.web.controller.communityCenter;


import com.mcwl.common.constant.HttpStatus;
import com.mcwl.common.core.domain.R;
import com.mcwl.common.core.page.PageDomain;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.communityCenter.domain.Community;
import com.mcwl.communityCenter.domain.dto.CommunityListPageRes;
import com.mcwl.communityCenter.domain.dto.CommunityRes;
import com.mcwl.communityCenter.domain.dto.JoinCommunityListPageRes;
import com.mcwl.communityCenter.domain.dto.JoinCommunityRes;
import com.mcwl.communityCenter.service.CommunityService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.Objects;

/**
 * 社区
 */
@Api(tags = "社区")
@RestController
@RequestMapping("community")
@RequiredArgsConstructor
public class CommunityController {

    private final CommunityService communityService;


    /**
     * 社区列表
     *
     * @return 社区列表
     */
    @ApiOperation(value = "社区列表")
    @PostMapping("list")
    public TableDataInfo getCommunityList(@RequestBody @Valid CommunityListPageRes communityListPageRes) {
        return communityService.listByPage(communityListPageRes);
    }


    /**
     * 我加入的社区
     */
    @ApiOperation(value = "我加入的社区")
    @PostMapping("myJoin")
    public TableDataInfo getMyJoinCommunity(@RequestBody JoinCommunityListPageRes joinCommunityListPageRes) {

        return communityService.getMyJoinCommunity(joinCommunityListPageRes);
    }


    /**
     * 添加社区
     *
     * @param communityRes 社区参数
     * @return 添加结果
     */
    @ApiOperation(value = "添加社区")
    @PostMapping("add")
    public R<Object> addCommunity(@RequestBody @Valid CommunityRes communityRes) {
        communityService.addCommunity(communityRes);
        return R.ok();
    }

    /**
     * 加入社区
     */
    @ApiOperation(value = "加入社区")
    @PostMapping("join")
    public R<Object> joinCommunity(@RequestBody @Valid JoinCommunityRes joinCommunityRes) {

        return communityService.joinCommunity(joinCommunityRes);
    }

    /**
     * 退出社区
     */
    @ApiOperation(value = "退出社区")
    @PostMapping("quit")
    public R<Object> quitCommunity(@ApiParam(value = "租户id", required = true)
                                   @NotNull(message = "租户id不能为空")
                                   @Valid
                                   Long tenantId,
                                   @ApiParam(value = "社区id", required = true)
                                   @NotNull(message = "社区id不能为空")
                                   @Valid
                                   Long communityId) {

        return communityService.quitCommunity(tenantId, communityId);
    }

    /**
     * 删除社区
     *
     * @param id 社区id
     * @return 删除结果
     */
    @ApiOperation(value = "删除社区")
    @GetMapping("delete")
    public R<Object> deleteCommunity(@NotNull(message = "id不能为空")
                                     @ApiParam(value = "id", required = true)
                                     @Valid
                                     Long id) {
        Community community = communityService.getById(id);
        if (Objects.isNull(community)) {
            return R.fail(HttpStatus.SHOW_ERROR_MSG, "该社区不存在");
        }
        communityService.removeById(id);
        return R.ok();
    }

    /**
     * 是否加入社区
     */
    @ApiOperation(value = "是否加入社区")
    @PostMapping("isJoin")
    public R<Object> isJoinCommunity(@RequestBody @Valid JoinCommunityRes joinCommunityRes) {

        return communityService.isJoinCommunity(joinCommunityRes);
    }

}
