package com.mcwl.communityCenter.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.constant.HttpStatus;
import com.mcwl.common.core.page.PageDomain;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.common.utils.obs.ObsUtils;
import com.mcwl.communityCenter.domain.CommunityFile;
import com.mcwl.communityCenter.domain.dto.*;
import com.mcwl.communityCenter.domain.vo.CommunityFileVo;
import com.mcwl.communityCenter.domain.vo.DownloadFileUserVo;
import com.mcwl.communityCenter.mapper.CommunityFileMapper;
import com.mcwl.communityCenter.service.CommunityFileLogService;
import com.mcwl.communityCenter.service.CommunityFileService;
import com.mcwl.system.service.ISysUserService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.util.*;

@Service
@RequiredArgsConstructor
public class CommunityFileServiceImpl extends ServiceImpl<CommunityFileMapper, CommunityFile> implements CommunityFileService {

    private final ObsUtils obsUtils;

    private final ISysUserService userService;

    private final CommunityFileLogService communityFileLogService;


    @Override
    public void upload(CommunityUploadFileRes communityUploadFileRes) {
        Long tenantId = communityUploadFileRes.getTenantId();
        Long communityId = communityUploadFileRes.getCommunityId();
        MultipartFile file = communityUploadFileRes.getFile();
        Map<String, String> map = obsUtils.uploadFile(file);
        String filename = file.getOriginalFilename();
        long fileSize = file.getSize();

        CommunityFile communityFile = CommunityFile.builder()
                .tenantId(tenantId)
                .communityId(communityId)
                .userId(SecurityUtils.getUserId())
                .fileUrl(map.get("path"))
                .objectKey(map.get("objectKey"))
                .fileName(filename)
                .fileSize(fileSize)
                .build();
        baseMapper.insert(communityFile);
    }

    @Override
    public TableDataInfo getCommunityFileList(CommunityFilePageListRes communityFilePageListRes) {
        Page<CommunityFile> page = new Page<>(communityFilePageListRes.getPageNum(), communityFilePageListRes.getPageSize());
        List<CommunityFileVo> communityFileList = baseMapper.getCommunityFileList(page, communityFilePageListRes);
        for (CommunityFileVo communityFileVo : communityFileList) {
            DownloadFileUserVo downloadFileUserVo = new DownloadFileUserVo();

            List<String> avatarList = communityFileLogService.getUserAvatarList(communityFileVo.getTenantId(),
                    communityFileVo.getCommunityId(),
                    communityFileVo.getId());
            Integer count = communityFileLogService.getDownloadCount(communityFileVo.getTenantId(),
                    communityFileVo.getCommunityId(),
                    communityFileVo.getId());

            downloadFileUserVo.setAvatarList(avatarList);
            downloadFileUserVo.setCount(count);


            communityFileVo.setDownloadFileUser(downloadFileUserVo);
        }
        // 封装返回
        TableDataInfo tableDataInfo = new TableDataInfo();
        tableDataInfo.setRows(communityFileList);
        tableDataInfo.setTotal(page.getTotal());
        tableDataInfo.setCode(HttpStatus.SUCCESS);
        tableDataInfo.setMsg("查询成功");
        return tableDataInfo;
    }
}
