package com.mcwl.communityCenter.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.constant.HttpStatus;
import com.mcwl.common.core.domain.R;
import com.mcwl.common.core.domain.entity.SysUser;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.common.utils.StringUtils;
import com.mcwl.communityCenter.domain.Community;
import com.mcwl.communityCenter.domain.CommunityUser;
import com.mcwl.communityCenter.domain.dto.BlackListRes;
import com.mcwl.communityCenter.domain.dto.CommunityListPageRes;
import com.mcwl.communityCenter.domain.dto.CommunityRes;
import com.mcwl.communityCenter.domain.dto.CommunityUserListPageRes;
import com.mcwl.communityCenter.domain.vo.CommunityUserVo;
import com.mcwl.communityCenter.domain.vo.CommunityVo;
import com.mcwl.communityCenter.mapper.CommunityMapper;
import com.mcwl.communityCenter.mapper.CommunityUserMapper;
import com.mcwl.communityCenter.service.CommunityService;
import com.mcwl.communityCenter.service.CommunityUserService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.time.temporal.ChronoUnit;
import java.util.*;

@Service
@RequiredArgsConstructor
public class CommunityUserServiceImpl extends ServiceImpl<CommunityUserMapper, CommunityUser> implements CommunityUserService {


    /**
     * 社区用户列表
     */
    @Override
    public TableDataInfo getCommunityUserList(CommunityUserListPageRes communityUserListPageRes) {
        Page<CommunityUser> page = new Page<>(communityUserListPageRes.getPageNum(), communityUserListPageRes.getPageSize());
        page.addOrder(new OrderItem("create_time", false));

        List<CommunityUserVo> communityUserList = baseMapper.getCommunityUserList(page, communityUserListPageRes);

        TableDataInfo tableDataInfo = new TableDataInfo();
        tableDataInfo.setRows(communityUserList);
        tableDataInfo.setTotal(page.getTotal());
        tableDataInfo.setCode(HttpStatus.SUCCESS);
        tableDataInfo.setMsg("查询成功");
        return tableDataInfo;
    }

    @Override
    public R<Object> black(BlackListRes blackListRes) {
        Long communityId = blackListRes.getCommunityId();
        Long userId = blackListRes.getUserId();
        Integer blackDay = blackListRes.getBlackDay();
        String blackReason = blackListRes.getBlackReason();

        CommunityUser communityUser = baseMapper.selectOne(new LambdaQueryWrapper<CommunityUser>()
                .eq(CommunityUser::getCommunityId, communityId)
                .eq(CommunityUser::getUserId, userId));
        if (Objects.isNull(communityUser)) {
            return R.fail(HttpStatus.SHOW_ERROR_MSG, "该用户不在该社区中");
        }

        Calendar calendar = Calendar.getInstance();
        calendar.add(Calendar.DATE, blackDay);

        communityUser.setIsBlank("1");
        communityUser.setBlankEndTime(calendar.getTime());
        communityUser.setBlackReason(blackReason);


        return R.ok();
    }
}
