package com.mcwl.communityCenter.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.constant.HttpStatus;
import com.mcwl.common.exception.ServiceException;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.common.utils.StringUtils;
import com.mcwl.communityCenter.constant.AdviceConstant;
import com.mcwl.communityCenter.domain.*;
import com.mcwl.communityCenter.domain.dto.PublishCommentLikeRes;
import com.mcwl.communityCenter.domain.dto.PublishLikeRes;
import com.mcwl.communityCenter.mapper.*;
import com.mcwl.communityCenter.service.PublishCommentLikeService;
import com.mcwl.communityCenter.service.PublishLikeService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Objects;

/**
 * 评论区点赞业务层
 */
@Service
@RequiredArgsConstructor
public class PublishLikeServiceImpl extends ServiceImpl<PublishLikeMapper, PublishLike> implements PublishLikeService {

    private final PublishMapper publishMapper;

    private final CommunityAdviceMapper communityAdviceMapper;


    @Override
    public void like(PublishLikeRes publishLikeRes) {

        Publish publish = publishMapper.selectByIdAndTenantIdAndCommunityId(publishLikeRes.getPublishId(),
                publishLikeRes.getTenantId(),
                publishLikeRes.getCommunityId());

        if (Objects.isNull(publish)) {
            throw new ServiceException("点赞失败，该内容不存在", HttpStatus.SHOW_ERROR_MSG);
        }

        PublishLike publishLike = baseMapper.selectPublishLike(publishLikeRes, SecurityUtils.getUserId());

        if (Objects.isNull(publishLike)) {
            publishLike = PublishLike.builder()
                    .tenantId(publishLikeRes.getTenantId())
                    .communityId(publishLikeRes.getCommunityId())
                    .publishId(publishLikeRes.getPublishId())
                    .userId(SecurityUtils.getUserId())
                    .build();
            baseMapper.insert(publishLike);

            publish.setLikeNum(publish.getLikeNum() + 1);
            publishMapper.updateById(publish);
            this.addLikeAdvice(publish);
            return;
        }

        if (Objects.equals(publishLike.getDelFlag(), "0")) {
            publishLike.setDelFlag("2");
            int likeNum = publish.getLikeNum() - 1;
            likeNum = Math.max(likeNum, 0);
            publish.setLikeNum(likeNum);
        } else {
            publishLike.setDelFlag("0");
            publish.setLikeNum(publish.getLikeNum() + 1);
            this.addLikeAdvice(publish);
        }

        baseMapper.updateDelFlagById(publishLike);
        publishMapper.updateById(publish);

    }

    private void addLikeAdvice(Publish publish) {
        CommunityAdvice communityAdvice = new CommunityAdvice();

        communityAdvice.setTenantId(publish.getTenantId());
        communityAdvice.setCommunityId(publish.getCommunityId());
        communityAdvice.setSendUserId(SecurityUtils.getUserId());
        communityAdvice.setAdviceType(AdviceConstant.COMMUNITY_NOTICE);
        communityAdvice.setUserId(publish.getUserId());
        communityAdvice.setContent(StringUtils.format("{}点赞了你发布的{}",
                SecurityUtils.getLoginUser().getUser().getNickName(), publish.getContent()));

        communityAdviceMapper.insert(communityAdvice);
    }
}
